@@ -33,8 +33,7 @@ class SenderEmailConfiguration(TimeStampedModel):
 
     sender_email_address = models.EmailField(
         max_length=254,
-        help_text='Enter sender email address to send log data from',
-        default='openlxphost@gmail.com')
+        help_text='Enter sender email address to send log data from')
 
     def save(self, *args, **kwargs):
         if not self.pk and SenderEmailConfiguration.objects.exists():
